%
%  multivltmomi.m   Date: 1/25/2016
%  This program computes E[prod_{i=1}^nX_i^{k_i}|X_i>a_i], where (X_1,..,X_n) 
%  follows a multivariate normal distribution with mean mu and covariance
%  matrix S, and lower truncation limits of a_i.  It is based on a binomial
%  expansion of the I integrals. 
%  Input:
%  kappa: power of X_i's
%  a: lower truncation limits
%  mu: E[X]
%  S: Var[X]
%  Output
%  M: E[\prod_{i=1}^nX_i^{I_i}|X_i>a_i], where I_i ranges from 0 to k_i
%
function M = multivltmomi(kappa,a,mu,S)
if size(kappa,1)>1
   kappa = kappa';
end
if size(a,2)>1
   a = a';
end
if size(mu,2)>1
   mu = mu';
end
n = length(mu);
eta = mu-a;
M1 = recint(kappa,eta,S);
pk = prod(kappa+1);
[out{1:n}] = ind2sub(kappa+1,[1:pk]');
kappa1 = cell2mat(out)-1;
%
%  Compute the moments of truncated multivariate normal
%
M = zeros(kappa+1);
ck = [1 cumprod(kappa(1:n-1)+1)]';
c0 = M1(1);
M(1) = c0;
for i=2:pk
    M(i) = binom(kappa1(i,:));
end
M = M/c0;

function y = binom(nu)
   x = zeros(1,n);
   c = 1;
   y = M1(nu*ck+1);  % first element
   ind1 = find(nu>0&a'~=0);
   for j=2:prod(nu(ind1)+1)
       for k=ind1
           if x(k)<nu(k)
              x(k) = x(k)+1;
              c = c*a(k)*(nu(k)-x(k)+1)/x(k);
              break
           else
              x(k) = 0;
              c = c/a(k)^nu(k);
           end
       end
       y = y+c*M1((nu-x)*ck+1);
   end
end
       
end    
    
    